@@ -1,5 +1,7 @@
 use crate::{
-  cli::{output_values_json, CreateTimeEntry, Format},
+  cli::{
+    output_values_json, CreateTimeEntry, Format, StartTimeEntry, StopTimeEntry,
+  },
   client::TogglClient,
   model::{Client, Project, Range, TimeEntry, Workspace},
 };
@@ -26,6 +28,12 @@ pub fn list(
   client: &TogglClient,
 ) -> anyhow::Result<()> {
   let mut time_entries = client.get_time_entries(range)?;
+
+  if time_entries.is_empty() {
+    println!("No entries found!");
+    return Ok(());
+  }
+
   let workspaces = client.get_workspaces()?;
   let me = client.get_me()?;
 
@@ -77,9 +85,16 @@ fn collect_output_entries(
     let maybe_client = maybe_project
       .and_then(|project| project.cid.and_then(|c| client_lookup.get(&c)));
 
+    // Running (Started, but not stopped) time_entries have a negative duration
+    let duration = if entry.duration.is_negative() {
+      Duration::zero()
+    } else {
+      Duration::seconds(entry.duration)
+    };
+
     output_entries.push(OutputEntry {
       date: entry.start.date().naive_local(),
-      duration: Duration::seconds(entry.duration),
+      duration,
       workspace: maybe_workspace
         .map(|w| w.name.to_owned())
         .unwrap_or_else(|| "-".to_string()),
@@ -97,7 +112,7 @@ fn collect_output_entries(
 }
 
 pub fn create(
-  _format: &Format,
+  format: &Format,
   time_entry: &CreateTimeEntry,
   client: &TogglClient,
 ) -> anyhow::Result<()> {
@@ -136,8 +151,6 @@ pub fn create(
       new_start,
       project.id,
     )?;
-
-    // FIXME: output entries of day
   } else {
     client.create_time_entry(
       &time_entry.description,
@@ -147,28 +160,125 @@ pub fn create(
       time_entry.start.as_date_time(),
       project.id,
     )?;
+  }
 
-    // FIXME: output entries of day
+  list(format, &Range::Today, client)?;
+
+  Ok(())
+}
+
+pub fn start(
+  format: &Format,
+  time_entry: &StartTimeEntry,
+  client: &TogglClient,
+) -> anyhow::Result<()> {
+  let me = client.get_me()?;
+  let workspace_id = me.data.default_wid;
+  let projects = client.get_workspace_projects(workspace_id)?;
+
+  let project = projects
+    .iter()
+    .find(|project| project.name == time_entry.project)
+    .ok_or(anyhow!(format!(
+      "Cannot find project='{}'",
+      time_entry.project
+    )))?;
+
+  let started_time_entry = client.start_time_entry(
+    &time_entry.description,
+    &time_entry.tags,
+    project.id,
+  )?;
+
+  match format {
+    Format::Json => output_values_json(&[started_time_entry.data]),
+    Format::Raw => output_time_entry_raw(&started_time_entry.data),
+    Format::Table => output_time_entry_table(&started_time_entry.data),
   }
 
   Ok(())
 }
 
+pub fn stop(
+  format: &Format,
+  time_entry: &StopTimeEntry,
+  client: &TogglClient,
+) -> anyhow::Result<()> {
+  let me = client.get_me()?;
+  let workspace_id = me.data.default_wid;
+  let projects = client.get_workspace_projects(workspace_id)?;
+
+  let project = projects
+    .iter()
+    .find(|project| project.name == time_entry.project)
+    .ok_or(anyhow!(format!(
+      "Cannot find project='{}'",
+      time_entry.project
+    )))?;
+
+  client.stop_time_entry(
+    time_entry.id,
+    &time_entry.description,
+    &time_entry.tags,
+    project.id,
+  )?;
+
+  list(format, &Range::Today, client)?;
+
+  Ok(())
+}
+
+fn output_time_entry_raw(time_entry: &TimeEntry) {
+  println!(
+    "{}\t{}\t{}\t{}",
+    &time_entry.id,
+    &time_entry.start,
+    &time_entry.description.to_owned().unwrap_or_default(),
+    &time_entry.tags.join(", "),
+  );
+}
+
+fn output_time_entry_table(time_entry: &TimeEntry) {
+  let mut table = Table::new();
+  table.style = TableStyle::thin();
+  table.separate_rows = false;
+
+  let header = Row::new(vec![
+    TableCell::new("Id".bold().underline()),
+    TableCell::new("Start".bold().underline()),
+    TableCell::new("Description".bold().underline()),
+    TableCell::new("Tags".bold().underline()),
+  ]);
+
+  table.add_row(header);
+
+  table.add_row(Row::new(vec![
+    TableCell::new(&time_entry.id),
+    TableCell::new(&time_entry.start),
+    TableCell::new(&time_entry.description.to_owned().unwrap_or_default()),
+    TableCell::new(&time_entry.tags.join(", ")),
+  ]));
+
+  println!("{}", table.render());
+}
+
 fn output_values_raw(output_entries: &[OutputEntry]) {
-  if !output_entries.is_empty() {
-    for entry in output_entries {
-      println!(
-        "{}\t{}\t{}\t{}\t{}\t{}",
-        &entry.date,
-        &entry.duration.hhmmss(),
-        &entry.workspace,
-        &entry.project,
-        &entry.client,
-        &entry.description
-      );
-    }
-  } else {
-    println!("No entries found");
+  for entry in output_entries {
+    let duration_text = if entry.duration.is_zero() {
+      "running ".to_string()
+    } else {
+      entry.duration.hhmmss()
+    };
+
+    println!(
+      "{}\t{}\t{}\t{}\t{}\t{}",
+      &entry.date,
+      duration_text,
+      &entry.workspace,
+      &entry.project,
+      &entry.client,
+      &entry.description
+    );
   }
 }
 
@@ -225,9 +335,15 @@ fn output_values_table(output_entries: &[OutputEntry]) {
       table.add_row(date_row);
 
       for entry in entries {
+        let duration_text = if entry.duration.is_zero() {
+          "running".italic()
+        } else {
+          entry.duration.hhmmss().italic()
+        };
+
         let entry_row = Row::new(vec![
           TableCell::new(""),
-          TableCell::new(&entry.duration.hhmmss().italic()),
+          TableCell::new(duration_text),
           TableCell::new(&entry.workspace),
           TableCell::new(&entry.project),
           TableCell::new(&entry.client),
@@ -315,7 +431,6 @@ mod tests {
       )
       .with_status(200)
       .with_body(projects().to_string())
-      .expect(1)
       .create();
 
     let request_body = json!(
@@ -360,6 +475,17 @@ mod tests {
       .expect(1)
       .create();
 
+    let list_entries_mock =
+      mock("GET", Matcher::Regex(r"^/time_entries.*$".to_string()))
+        .with_header(
+          "Authorization",
+          "Basic Y2I3YmY3ZWZhNmQ2NTIwNDZhYmQyZjdkODRlZTE4YzE6YXBpX3Rva2Vu",
+        )
+        .with_status(200)
+        .expect(1)
+        .with_body("[]")
+        .create();
+
     {
       let workday_with_pause = CreateTimeEntry {
         description: "fkbr".to_string(),
@@ -381,6 +507,7 @@ mod tests {
     me_mock.assert();
     projects_mock.assert();
     time_entry_create_mock.assert();
+    list_entries_mock.assert();
 
     Ok(())
   }
@@ -404,7 +531,6 @@ mod tests {
       )
       .with_status(200)
       .with_body(projects().to_string())
-      .expect(1)
       .create();
 
     let first_request_body = json!(
@@ -491,6 +617,17 @@ mod tests {
       .expect(1)
       .create();
 
+    let list_entries_mock =
+      mock("GET", Matcher::Regex(r"^/time_entries.*$".to_string()))
+        .with_header(
+          "Authorization",
+          "Basic Y2I3YmY3ZWZhNmQ2NTIwNDZhYmQyZjdkODRlZTE4YzE6YXBpX3Rva2Vu",
+        )
+        .with_status(200)
+        .expect(1)
+        .with_body("[]")
+        .create();
+
     {
       let workday_with_pause = CreateTimeEntry {
         description: "fkbr".to_string(),
@@ -513,6 +650,7 @@ mod tests {
     projects_mock.assert();
     first_time_entry_create_mock.assert();
     second_time_entry_create_mock.assert();
+    list_entries_mock.assert();
 
     Ok(())
   }
